==> haskell-wai-app-static-3.1.6.1-70-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-wai-app-static.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-app-static
version: 3.1.6.1
id: wai-app-static-3.1.6.1-98JSOZ7O0KJ4xK1AR0WjQo
key: wai-app-static-3.1.6.1-98JSOZ7O0KJ4xK1AR0WjQo
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
stability: Stable
homepage: http://www.yesodweb.com/book/web-application-interface
synopsis: WAI application for static serving
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-app-static>.
category: Web, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
exposed-modules:
    Network.Wai.Application.Static WaiAppStatic.Storage.Filesystem
    WaiAppStatic.Storage.Embedded WaiAppStatic.Listing
    WaiAppStatic.Types WaiAppStatic.CmdLine
hidden-modules: Util WaiAppStatic.Storage.Embedded.Runtime
                WaiAppStatic.Storage.Embedded.TH
abi: 5e6c13d8f4c18689ab74d2eeee9cc0cc
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/wai-app-static-3.1.6.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/wai-app-static-3.1.6.1
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/wai-app-static-3.1.6.1
hs-libraries: HSwai-app-static-3.1.6.1-98JSOZ7O0KJ4xK1AR0WjQo
depends:
    base-4.9.0.0 blaze-builder-0.4.0.2-J9puUMdRFvA3rt0D0pNg3S
    blaze-html-0.8.1.3-5umpHbJSFbGGX5TQ5mnIPt
    blaze-markup-0.7.1.1-VJaDzmYXPW8F1IHSBweDX bytestring-0.10.8.1
    containers-0.5.7.1 cryptonite-0.23-3GIkE0SDPeuXan48X60bd
    directory-1.2.6.2 file-embed-0.0.10-IXfudWSq57y1Athysk5ifZ
    filepath-1.4.1.0 http-date-0.0.6.1-FJ5pCrDwrRfB0fakx8ks9k
    http-types-0.9.1-3nvMCSru4dgGbycKqlKoUe
    memory-0.14.6-300MPYpxHNH28XjtXjOwph
    mime-types-0.1.0.7-IGNudFuuwMMBpnhWYuIBl8
    old-locale-1.0.0.7-6glXNhHF891B41ZfuI8hU8
    optparse-applicative-0.13.2.0-7Y0agREbHDlBXdHE81XeQP
    template-haskell-2.11.0.0 text-1.2.2.2-9rr3K4o0GAG9P33dGDnV9v
    time-1.6.0.1 transformers-0.5.2.0
    unix-compat-0.4.3.1-GamCWWfiT0318wIeUlpE1K
    unordered-containers-0.2.8.0-Njz6QHP7Gk5G9PhT6D28J
    wai-3.2.1.1-OfWV8JQuvWB8nxi8pXkD1
    wai-extra-3.0.19.1-L5JgLyi1q7HAGLg6MtRGp7
    warp-3.2.12-6Y4kitQMsI8Cw3Gag1W6lt
    zlib-0.6.1.2-1dMv6Gv8Q4W22Ei4thcEsU
haddock-interfaces: /usr/share/doc/haskell-wai-app-static/html/wai-app-static.haddock
haddock-html: /usr/share/doc/haskell-wai-app-static/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-app-static-3.1.6.1-71-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-wai-app-static.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-app-static
version: 3.1.6.1
id: wai-app-static-3.1.6.1-3EHEtcerNrM3XchOu1nnT7
key: wai-app-static-3.1.6.1-3EHEtcerNrM3XchOu1nnT7
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
stability: Stable
homepage: http://www.yesodweb.com/book/web-application-interface
synopsis: WAI application for static serving
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-app-static>.
category: Web, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
exposed-modules:
    Network.Wai.Application.Static WaiAppStatic.Storage.Filesystem
    WaiAppStatic.Storage.Embedded WaiAppStatic.Listing
    WaiAppStatic.Types WaiAppStatic.CmdLine
hidden-modules: Util WaiAppStatic.Storage.Embedded.Runtime
                WaiAppStatic.Storage.Embedded.TH
abi: a49e188355255e856a417ba977f3315a
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/wai-app-static-3.1.6.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/wai-app-static-3.1.6.1
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/wai-app-static-3.1.6.1
hs-libraries: HSwai-app-static-3.1.6.1-3EHEtcerNrM3XchOu1nnT7
depends:
    base-4.9.0.0 blaze-builder-0.4.0.2-J9puUMdRFvA3rt0D0pNg3S
    blaze-html-0.8.1.3-5umpHbJSFbGGX5TQ5mnIPt
    blaze-markup-0.7.1.1-VJaDzmYXPW8F1IHSBweDX bytestring-0.10.8.1
    containers-0.5.7.1 cryptonite-0.23-3GIkE0SDPeuXan48X60bd
    directory-1.2.6.2 file-embed-0.0.10-IXfudWSq57y1Athysk5ifZ
    filepath-1.4.1.0 http-date-0.0.6.1-FJ5pCrDwrRfB0fakx8ks9k
    http-types-0.9.1-3nvMCSru4dgGbycKqlKoUe
    memory-0.14.6-300MPYpxHNH28XjtXjOwph
    mime-types-0.1.0.7-IGNudFuuwMMBpnhWYuIBl8
    old-locale-1.0.0.7-6glXNhHF891B41ZfuI8hU8
    optparse-applicative-0.13.2.0-7Y0agREbHDlBXdHE81XeQP
    template-haskell-2.11.0.0 text-1.2.2.2-9rr3K4o0GAG9P33dGDnV9v
    time-1.6.0.1 transformers-0.5.2.0
    unix-compat-0.4.3.1-GamCWWfiT0318wIeUlpE1K
    unordered-containers-0.2.8.0-Njz6QHP7Gk5G9PhT6D28J
    wai-3.2.1.1-OfWV8JQuvWB8nxi8pXkD1
    wai-extra-3.0.19.1-DPKQPEnm6Hz8g8OT5FuUpO
    warp-3.2.12-6Y4kitQMsI8Cw3Gag1W6lt
    zlib-0.6.1.2-1dMv6Gv8Q4W22Ei4thcEsU
haddock-interfaces: /usr/share/doc/haskell-wai-app-static/html/wai-app-static.haddock
haddock-html: /usr/share/doc/haskell-wai-app-static/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
